@@ -264,7 +264,7 @@ static void OpenDV()
     for( i=0; i<nDVDevices; ++i)
     {
             QTAtom isochAtom, dataAtom;
-            UInt32 test[2];
+            UInt64 test;
             int nConfigs;
             char cameraName[256];
             IDHDeviceID deviceID;
@@ -280,8 +280,8 @@ static void OpenDV()
             dataAtom = QTFindChildByIndex( deviceList, deviceAtom, kIDHUniqueIDType, 1, nil);
             if( dataAtom == nil)
                     goto error;
-            QTCopyAtomDataToPtr( deviceList, dataAtom, true, sizeof( test), test, &size);
-            printf("guid 0x%x%08x ", test[0], test[1]);
+            QTCopyAtomDataToPtr( deviceList, dataAtom, true, sizeof( test), &test, &size);
+            printf("guid 0x%016llx ", test);
             dataAtom = QTFindChildByIndex( deviceList, deviceAtom, kIDHNameAtomType, 1, nil);
             if( dataAtom == nil)
                     goto error;
@@ -371,7 +371,7 @@ static void OpenDV()
                     printf("\n");
             }
             printf("-----\n");
-            if(sGUID == (((UInt64)test[0]) << 32) + test[1])
+            if(sGUID == test)
                 break;
     }
 
